from __future__ import print_function

from .__version__ import __url__, __version__


if __name__ == '__main__':  # pragma no cover
    print('SteelConnection version:', __version__)
    print('Project home:', __url__)
